import { addDish, updataDish, getDishById, getDishList, getFoodIngredientsList } from '@/services/api/dish';
import { queryTable } from '@/utils/request';
import { PageContainer, ProForm, ProFormDigit, ProFormText, ModalForm, ProFormSelect } from '@ant-design/pro-components';
import { history, useSearchParams } from '@umijs/max';
import { Card, Col, message, Row, Space, Image, Select, Option } from 'antd';
import { values } from 'lodash';
import { useEffect, useRef, useState } from 'react';

export default (props) => {
  const [searchParams] = useSearchParams();
  const id = searchParams.get('id');
  const [datas, setDatas] = useState([]);
  const [data, setData] = useState({});
  const formRef = useRef();
  useEffect(() => {

    getFoodIngredientsList().then((res) => {
      setDatas(res?.records?.map((x) => ({
        label: x.name,
        value: x.dishId
      })))

    });
  }, [id]);

  useEffect(() => {
    if (id) {
      getDishById(id).then((res) => {
        setData(res);

        formRef.current.setFieldsValue(res);
      });
    }
  }, [id]);

  const onFinish = async (values) => {


    if (id) {
      // 修改
      updataDish(id, { ...values }).then((res) => {
        message.success('修改成功');
        history.back();
      });
    } else {
      // 新增
      addDish({ ...values }).then((res) => {
        message.success('添加成功');
        history.back();
      });
    }

    return false;
  };
  console.log("datas", datas)
  return (
    <PageContainer>
      <Card>
        <ProForm
          formRef={formRef}
          layout={'horizontal'}
          labelCol={{ span: 8 }}
          wrapperCol={{ span: 16 }}
          onFinish={onFinish}
          initialValues={{ type: '1', state: '1' }}
          submitter={{
            searchConfig: {
              resetText: '返回',
            },
            onReset: () => history.back(),
            render: (props, doms) => {
              return (
                <Row>
                  <Col span={8} offset={8}>
                    <Space>{doms}</Space>

                  </Col>
                </Row>
              );
            },
          }}
        >
          <ProFormText name="name" label="菜肴名称" placeholder="请输入菜肴名称" width={460} />
          <ProFormText name="unit" label="菜肴单位" placeholder="请输入菜肴单位" width={460} />
          <ProFormSelect mode="multiple" label="包含食材" placeholder="多选下拉" width={460}
            options={datas}
          />
        </ProForm>
      </Card>
    </PageContainer>

  );
};